==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Limpiar todo</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centro de notificaciones</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Limpiar todo</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desfijar</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fijar</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ajustes de notificaciones</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Ahora mismo</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Hace %1 minutos</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Hace una hora</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Hace %1 horas</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Ayer </translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Limpiar todo</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centro de notificaciones</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Limpiar todo</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desfijar</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fijar</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ajustes de notificaciones</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Ahora mismo</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Hace %1 minutos</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Hace una hora</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Hace %1 horas</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Ayer </translation>
    </message>
</context>
</TS>
